print("hello!")
print("HIII")
from Computers import Computers




"""
import requests
import logging
import json
import sys
import os
sys.path.append(os.getcwd())
from Computers import Computers

logging.basicConfig(level=logging.DEBUG)
#client_id = input("Client ID: ")
#api_key = input("API Key: ")
client_id = "20a77b2b4743c0431fea"
api_key = "61a05de2-8e27-404b-b419-218f2f6ed0d4"
auth = (client_id, api_key)

class Version:
    def __init__(self):
        r = requests.get("https://api.amp.cisco.com/v1/version", auth=auth)
        if r.status_code == 200:
            print("Authenticated")
            logging.log(logging.DEBUG, "DEBUG Message AUTH good")
        print(r)


class Computer:
    def __init__(self):
        self.foo = "bar"



class Auth:
    def __init__(self, client_id, api_key):
        self.client_id = client_id
        self.api_key = api_key


c = Computers()

v = Version()
print(v)

"""


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="a4e-bmacer",
    version="0.0.5",
    author="Brandon Macer",
    author_email="bmacer@cisco.com",
    description="A package for using AMP for Endpoint API",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/pypa/a4e",
    packages=setuptools.find_packages(),
    install_requires=[
        "requests"
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)


import requests
import logging
from Auth import auth

class Computers:
    def __init__(self):
        url = "https://api.amp.cisco.com/v1/computers"
        r = requests.get(url, auth=auth)
        if r.status_code != 200:
            raise Exception(f"Non-200 Status Code: {r.status_code}")
        self.status_code = r.status_code
        logging.log(logging.DEBUG, f"Computers: {r}")